[![Datatailr Logo](https://framerusercontent.com/images/6CmFcG0o2ryoa5cMuDsvwESVWA.svg)](https://www.datatailr.com/)

___
**Datatailr empowers your team to streamline analytics and data workflows
from idea to production without infrastructure hurdles.**

## What is Datatailr?

Datatailr is a platform that simplifies the process of building and deploying data applications.

It makes it easier to run and maintain large-scale data processing and analytics workloads.

## What is this package?
This is the Python package for Datatailr, which allows you to interact with the Datatailr platform.

It provides the tools to build, deploy, and manage batch jobs, data pipelines, services and analytics applications.

Datatailr manages the underlying infrastructure so your applications can be deployed in an easy, secure and scalable way.

## Installation

### Installing the `dt` command line tool
Before you can use the Datatailr Python package, you need to install the `dt` command line tool.
**[INSTALLATION INSTRUCTIONS FOR DATATAILR GO HERE]**

### Installing the Python package
You can install the Datatailr Python package using pip:
```bash
pip install datatailr
```

### Testing the installation
```python
import datatailr

print(datatailr.__version__)
print(datatailr.__provider__)
```


## Quickstart


___
Visit [our website](https://www.datatailr.com/) for more!
